"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const format_1 = __importDefault(require("./format"));
const levels = ["silent", "error", "warn", "info", "debug"];
function createLogger(level, formatterFactory = level => (message, rest) => format_1.default(level, message, rest)) {
    const configuredLevelIndex = levels.indexOf(level);
    if (configuredLevelIndex === -1) {
        throw new Error(`Invalid log level "${level}". Allowed levels: ${levels.join(", ")}`);
    }
    return levels.reduce((logger, l, i) => {
        const formatter = formatterFactory(l);
        if (l !== "silent") {
            logger[l] =
                i <= configuredLevelIndex
                    ? (message, ...rest) => {
                        const dt = formatter(message, rest);
                        console.log.apply(console, dt.optionalParams
                            ? [dt.message, ...dt.optionalParams]
                            : [dt.message]);
                    }
                    : noOp;
        }
        return logger;
    }, {});
}
exports.default = createLogger;
const noOp = () => { };
//# sourceMappingURL=index.js.map